PlaidLinkAccount class

Account metadata returned by Plaid Link.

Constructors

PlaidLinkAccount({required String id, required String? mask, required String name, required String type, required String subtype, required String? verificationStatus})
Creates Plaid account metadata.
PlaidLinkAccount.fromJson(dynamic json)
Creates account metadata from JSON-like map data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Plaid account identifier.
final
mask String?
Masked account number, when available.
final
name String
Account display name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtype String
Plaid account subtype.
final
type String
Plaid account type.
final
verificationStatus String?
Verification status, when available.
final

Methods

description() String
Returns a readable description of the account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this account to JSON-like map data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited