PlaidLinkInstitution class

Institution metadata returned by Plaid Link.

Constructors

PlaidLinkInstitution({required String id, required String name})
Creates Plaid institution metadata.
PlaidLinkInstitution.fromJson(dynamic json)
Creates institution metadata from JSON-like map data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Plaid institution identifier.
final
name String
Plaid institution display name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

description() String
Returns a readable description of the institution.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this institution to JSON-like map data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited