PlaidLinkSuccessMetadata class

Metadata returned by a successful Plaid Link session.

Constructors

PlaidLinkSuccessMetadata({required String linkSessionId, required PlaidLinkInstitution? institution, required List<PlaidLinkAccount> accounts})
Creates Plaid Link success metadata.
PlaidLinkSuccessMetadata.fromJson(dynamic json)
Creates metadata from JSON-like map data.
factory

Properties

accounts List<PlaidLinkAccount>
Accounts selected by the user.
final
hashCode int
The hash code for this object.
no setterinherited
institution PlaidLinkInstitution?
Institution selected by the user.
final
linkSessionId String
Plaid Link session identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

description() String
Returns a readable description of the metadata.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this metadata to JSON-like map data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited