PlaidLinkManagerImpl class
Opens Plaid Link and forwards success, event, and exit callbacks.
- Inheritance
-
- Object
- PlaidLinkManager
- PlaidLinkManagerImpl
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openPlaidLink(
String plaidLink, PlaidLinkSuccessCallback onSuccess, PlaidLinkEventCallback onEvent, PlaidLinkErrorCallback onExit) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited