PlaidLinkSuccess class
Successful Plaid Link result exposed to Ensemble.
Constructors
- PlaidLinkSuccess({required String publicToken, required PlaidLinkSuccessMetadata metadata})
- Creates a successful Plaid Link result.
- PlaidLinkSuccess.fromLinkSuccess(LinkSuccess data)
-
Converts a
plaid_fluttersuccess payload into an Ensemble model.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → PlaidLinkSuccessMetadata
-
Metadata returned with the successful Plaid Link result.
final
- publicToken → String
-
Public token returned by Plaid Link.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this result to JSON-like map data.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited